### this is the analysis of one person's data

datafilename = "taskswitching.psy.2012-12-16-1341.data"

### read data into table

data         = read.table( datafilename )
correct      = data[,8]==1 # flag correct trial
n            = dim(data)[1]  # number of trials
pureblock    = data[,6]!=0
mixedblock   = data[,6]==0
taskrepeat   = data[,7]==0
taskswitch   = data[,7]==1
rt           = data[,9]

### now report average response times in correct trials

pureblockspeed        = mean( rt[ pureblock & taskrepeat & correct ] )
mixedblockrepeatspeed = mean( rt[ mixedblock & taskrepeat & correct ] )
mixedblockswitchspeed = mean( rt[ mixedblock & taskswitch & correct ] )

print("Response speed in milliseconds")
print("Pure blocks")
print( pureblockspeed )
print("Mixed block task repeat")
print( mixedblockrepeatspeed )
print("Mixed block task switch")
print( mixedblockswitchspeed )

print("Task switch cost in response speed is:")
print( mixedblockswitchspeed - mixedblockrepeatspeed )

print("Mixing cost is in response speed is:")
print( mixedblockrepeatspeed - pureblockspeed )

### now report error rates

pureblockErrorRate = sum( pureblock & taskrepeat & !correct ) / sum( pureblock & taskrepeat ) * 100 
mixedblockRepeatErrorRate = sum( mixedblock & taskrepeat & !correct ) / sum( mixedblock & taskrepeat ) * 100 
mixedblockSwitchErrorRate = sum( mixedblock & taskswitch & !correct ) / sum( mixedblock & taskswitch ) * 100 

cat("-------------------------------------\n")
print("Error rates: (if people make few mistakes, these are not very interesting")
print("Error rate in Pure blocks")
print( pureblockErrorRate )

print("Error rate in Mixed block task repeat")
print( mixedblockRepeatErrorRate )

print("Error rate in Mixed block task switch")
print( mixedblockSwitchErrorRate )

print("Task switch cost in error rates is:")
print( mixedblockSwitchErrorRate - mixedblockRepeatErrorRate )

print("Mixing cost is in error rates is:")
print( mixedblockRepeatErrorRate - pureblockErrorRate )
